summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMad Physicist <madphysicist@users.noreply.github.com>2016-03-25 14:55:31 -0400
committerMad Physicist <madphysicist@users.noreply.github.com>2016-03-25 14:55:31 -0400
commit5a4ed43df82405dcd5fc02a86fbb6d97476d2961 (patch)
tree71d7e7a04c5d876c983629d4513666ce9ff5f94b
parent58dfec695e8732df03a6509070938385a82d7c4d (diff)
downloadnatsort-5a4ed43df82405dcd5fc02a86fbb6d97476d2961.tar.gz
DOC: Changed "sequence" to "iterable"
Seemed like a good idea since I had to try it out before deciding that the docs were not precise.
-rw-r--r--natsort/natsort.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/natsort/natsort.py b/natsort/natsort.py
index 6f90bf9..b69021a 100644
--- a/natsort/natsort.py
+++ b/natsort/natsort.py
@@ -189,19 +189,19 @@ def natsort_keygen(key=None, alg=0, **_kwargs):
@u_format
def natsorted(seq, key=None, reverse=False, alg=0, **_kwargs):
"""\
- Sorts a sequence naturally.
+ Sorts an iterable naturally.
- Sorts a sequence naturally (alphabetically and numerically),
- not lexicographically. Returns a new copy of the sorted
- sequence as a list.
+ Sorts an iterable naturally (alphabetically and numerically),
+ not lexicographically. Returns a list containing a sorted copy
+ of the iterable.
Parameters
----------
seq : iterable
- The sequence to sort.
+ The iterable to sort.
key : callable, optional
A key used to determine how to sort each element of the sequence.
It is **not** applied recursively.
It should accept a single argument and return a single value.
@@ -189,19 +189,19 @@ def natsort_keygen(key=None, alg=0, **_kwargs):
key : callable, optional
- A key used to determine how to sort each element of the sequence.
+ A key used to determine how to sort each element of the iterable.
It is **not** applied recursively.
It should accept a single argument and return a single value.